@@ -1,6 +1,6 @@
 package Data::Perl::Collection::Array;
 {
-  $Data::Perl::Collection::Array::VERSION = '0.001000';
+  $Data::Perl::Collection::Array::VERSION = '0.001001';
 }
 
 # ABSTRACT: Wrapping class for Perl's built in array structure.
@@ -99,7 +99,7 @@ Data::Perl::Collection::Array - Wrapping class for Perl's built in array structu
 
 =head1 VERSION
 
-version 0.001000
+version 0.001001
 
 =head1 SYNOPSIS
 
@@ -388,11 +388,11 @@ references in the clone.
 
 =head1 AUTHOR
 
-Matthew Phillips <mattp(at)cpan.org>
+Matthew Phillips <mattp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Matthew Phillips <mattp(at)cpan.org>.
+This software is copyright (c) 2013 by Matthew Phillips <mattp@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
